#
# spec file for package soapy-bladerf
#
# Copyright (c) 2025, SUSE LLC
# Copyright (c) 2017, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define soapy_modver 0.8
%define soapy_modname soapysdr%{soapy_modver}-module-bladerf

Name:           soapy-bladerf
Version:        0.4.2
Release:        1.1
Summary:        SoapySDR BladeRF module
License:        LGPL-2.1
Group:          Hardware/Other
Url:            https://github.com/pothosware/SoapyBladeRF/wiki
#Git-Clone:     https://github.com/pothosware/SoapyBladeRF.git
Source:         https://github.com/pothosware/SoapyBladeRF/archive/%{name}-%{version}.tar.gz#/SoapyBladeRF-%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  soapy-sdr-devel
BuildRequires:  bladeRF-devel

%description
Soapy BladeRF - BladeRF device support for Soapy SDR.
A Soapy module that supports BladeRF devices within the Soapy API.

%package -n %{soapy_modname}
Summary:        SoapySDR BladeRF module
Group:          System/Libraries

%description -n %{soapy_modname}
Soapy BladeRF - BladeRF device support for Soapy SDR.
A Soapy module that supports BladeRF devices within the Soapy API.

%prep
%setup -q -n SoapyBladeRF-%{name}-%{version}

%build
%cmake
%cmake_build

%install
%cmake_install

%check

%files -n %{soapy_modname}
%license LICENSE.LGPLv2.1
%doc Changelog.txt README.md
%dir %{_libdir}/SoapySDR
%dir %{_libdir}/SoapySDR/modules%{soapy_modver}
%{_libdir}/SoapySDR/modules%{soapy_modver}/libbladeRFSupport.so

%changelog
* Fri Jan 24 2025 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 0.4.2 (2024-12-22)
  * Added support for PLL reference clock
  * Added uninstall target
  * Updates for dual channel streaming
  * Added biastee_tx and biastee_rx options
  * Added saveQuickTune and reuseQuickTune args to setFrequency
  * Added flags for BLADERF_META_FLAG_RX_HW_MINIEXP1&2
  * Print gain mode on config
  * Allow turning bias tee off
- Specfile update, add empty %%check section
- Do not require pkgconfig for build
* Tue Jul  6 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- SoapySDR version bumped to 0.8
* Sun Jan 27 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 0.4.1
  * Support for MIMO 2x channel streams
  * Added bladerfv2 RSSI and Temperature sensors
  * Added bladerfv2 RFIC register access
  * Switch to name-based register access API
  * Range and gain stage APIs for gain, bandwidth, frequency
  * Remove ifdefs for v2 and other version conditionals, this is
    too complicated to maintain across versions.
* Thu Dec 13 2018 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 0.4.0
  * Support for version2 of the libbladerf API
* Sat Nov 10 2018 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update soapy-module version 0.6 -> 0.7
* Sat Oct 20 2018 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to latest 0.3.5 git 20181015
* Tue Oct  2 2018 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to latest 0.3.5 git 20180908
- works with libbladerf ver. 2
* Fri May  5 2017 mardnh@gmx.de
- Update to version 0.3.3
  * Added label convention to bladerf discovery routine
  * Update debian files for SoapySDR module ABI format
* Wed Apr 19 2017 mardnh@gmx.de
- renamed packages according the debian package name from upstream
* Fri Apr 14 2017 mardnh@gmx.de
- Update to version 0.3.2 (tagged release)
- renamed package from SoapyBladeRF to soapy-bladerf
- specfile cleanup
* Tue Jan  3 2017 mardnh@gmx.de
- Update to version 0.3.2.git1472794191.c83cc2b:
  * fix typo in debian copyright file
  * bladerf: Implemented masked GPIO write
  * Fix tx end of burst implementation in deactivateStream()
  * clear EOB when the last sample will not be transmitted
  * bladerf: changelog entry for 0.3.1
  * user patch for xb200 support and loopback hooks
  * fix logger calls, added c++11, compiling
  * apply matching device args to settings
  * separate project and debian changelogs
  * changelog entries for settings work
  * added c++11 flags for OSX
  * bladerf: changelog entry for 0.3.2
  * debian: update for soapySDR module ABI format
  * debian: fixed rules executable bit
* Tue Dec  8 2015 mardnh@gmx.de
- Update to version 0.2.0.git1448058413.43cf191:
  + bladerf: implement new stream info calls
  + bladerf: fix STRINGIFY for default arguments
  + travis: added travis ci for SoapyBladeRF
* Sun Oct 11 2015 mardnh@gmx.de
- initial package
